@@ -3,7 +3,7 @@ package RiveScript;
 use strict;
 use warnings;
 
-our $VERSION = '1.34'; # Version of the Perl RiveScript interpreter.
+our $VERSION = '1.38'; # Version of the Perl RiveScript interpreter.
 our $SUPPORT = '2.0';  # Which RS standard we support.
 our $basedir = (__FILE__ =~ /^(.+?)\.pm$/i ? $1 : '.');
 
@@ -364,6 +364,18 @@ sub parse {
 	my $lastcmd = '';       # Last command code.
 	my $isThat  = '';       # Is a %Previous trigger.
 
+	# Local (file scoped) parser options.
+	my %local_options = (
+		concat => "none", # Concat mode for ^Continue command.
+	);
+
+	# Concat mode characters.
+	my %concat_mode = (
+		none    => "",
+		space   => " ",
+		newline => "\n",
+	);
+
 	# Split the RS code into lines.
 	$code =~ s/([\x0d\x0a])+/\x0a/ig;
 	my @lines = split(/\x0a/, $code);
@@ -536,7 +548,10 @@ sub parse {
 				if ($cmd ne '^' && $lookCmd ne '%') {
 					if ($lookCmd eq '^') {
 						$self->debug ("\t^ [$lp;$i] $lookahead");
-						$line .= $lookahead;
+						my $concat = exists $concat_mode{$local_options{"concat"}}
+							? $concat_mode{$local_options{"concat"}}
+							: "";
+						$line .= $concat . $lookahead;
 					}
 					else {
 						last;
@@ -564,6 +579,10 @@ sub parse {
 					return;
 				}
 			}
+			elsif ($type eq 'local') {
+				$self->debug ("\tSet local parser option $var = $value");
+				$local_options{$var} = $value;
+			}
 			elsif ($type eq 'global') {
 				if (not defined $var) {
 					$self->issue ("Undefined global variable at $fname line $lineno.");
@@ -933,7 +952,7 @@ sub checkSyntax {
 		my @chr = split(//, $line);
 		for (my $i = 0; $i < scalar(@chr); $i++) {
 			my $char = $chr[$i];
-			
+
 			# Count brackets.
 			$parens++  if $char eq '('; $parens--  if $char eq ')';
 			$square++  if $char eq '['; $square--  if $char eq ']';
@@ -1173,20 +1192,12 @@ sub sortReplies {
 			$track->{ ($highest_inherits + 1) } = delete $track->{'-1'}; # Move the no-{inherits} group away for a sec
 			foreach my $ip (sort { $a <=> $b } keys %{$track}) {
 				$self->debug("ip=$ip");
-				foreach my $i (sort { $b <=> $a } keys %{$track->{$ip}->{atomic}}) {
-					push (@running,@{$track->{$ip}->{atomic}->{$i}});
-				}
-				foreach my $i (sort { $b <=> $a } keys %{$track->{$ip}->{option}}) {
-					push (@running,@{$track->{$ip}->{option}->{$i}});
-				}
-				foreach my $i (sort { $b <=> $a } keys %{$track->{$ip}->{alpha}}) {
-					push (@running,@{$track->{$ip}->{alpha}->{$i}});
-				}
-				foreach my $i (sort { $b <=> $a } keys %{$track->{$ip}->{number}}) {
-					push (@running,@{$track->{$ip}->{number}->{$i}});
-				}
-				foreach my $i (sort { $b <=> $a } keys %{$track->{$ip}->{wild}}) {
-					push (@running,@{$track->{$ip}->{wild}->{$i}});
+				foreach my $kind (qw(atomic option alpha number wild)) {
+					foreach my $wordcnt (sort { $b <=> $a } keys %{$track->{$ip}->{$kind}}) {
+						# Triggers with a matching word count should be sorted
+						# by length, descending.
+						push (@running, sort { length($b) <=> length($a) } @{$track->{$ip}->{$kind}->{$wordcnt}});
+					}
 				}
 				push (@running, sort { length($b) <=> length($a) } @{$track->{$ip}->{under}});
 				push (@running, sort { length($b) <=> length($a) } @{$track->{$ip}->{pound}});
@@ -1597,8 +1608,10 @@ sub deparse {
 			person   => {},
 			array    => {},
 			triggers => {},
+			that     => {},
 		},
 		topic   => {},
+		that    => {},
 		inherit => {},
 		include => {},
 	};
@@ -1647,14 +1660,14 @@ sub deparse {
 
 		if ($topic eq "__begin__") {
 			# Begin block.
-			$dest = $deparse->{begin}->{triggers};
+			$dest = $deparse->{begin}->{that};
 		}
 		else {
 			# Normal topic.
-			if (!exists $deparse->{topic}->{$topic}) {
-				$deparse->{topic}->{$topic} = {};
+			if (!exists $deparse->{that}->{$topic}) {
+				$deparse->{that}->{$topic} = {};
 			}
-			$dest = $deparse->{topic}->{$topic};
+			$dest = $deparse->{that}->{$topic};
 		}
 
 		# The "that" structure is backwards: bot reply, then trigger, then info.
@@ -1755,12 +1768,29 @@ sub write {
 	foreach my $sort (qw/global var sub person array/) {
 		next unless scalar keys %{$deparse->{begin}->{$sort}} > 0;
 		foreach my $var (sort keys %{$deparse->{begin}->{$sort}}) {
-			my $value = ref($deparse->{begin}->{$sort}->{$var}) ?
-				join("|", @{$deparse->{begin}->{$sort}->{$var}}) :
-				$deparse->{begin}->{$sort}->{$var};
+			# Array types need to be separated by either spaces or pipes.
+			my $data = $deparse->{begin}->{$sort}->{$var};
+			if (ref($data) eq "ARRAY") {
+				my $needs_pipes = 0;
+				foreach my $test (@{$data}) {
+					if ($test =~ /\s+/) {
+						$needs_pipes = 1;
+						last;
+					}
+				}
 
-			print {$fh} "! $sort $var = " . $self->_write_wrapped($value,
-				$sort eq "array" ? "|" : " ") . "\n";
+				# Word-wrap the result, target width is 78 chars minus the
+				# sort, var, and spaces and equals sign.
+				my $width = 78 - length($sort) - length($var) - 4;
+
+				if ($needs_pipes) {
+					$data = $self->_write_wrapped(join("|", @{$data}), "|", undef, $width);
+				} else {
+					$data = join(" ", @{$data});
+				}
+			}
+
+			print {$fh} "! $sort $var = $data\n";
 		}
 		print {$fh} "\n";
 	}
@@ -1798,6 +1828,11 @@ sub write {
 
 		$self->_write_triggers($fh, $deparse->{topic}->{$topic}, $tagged ? "indent" : 0);
 
+		# Any %Previous's?
+		if (exists $deparse->{that}->{$topic}) {
+			$self->_write_triggers($fh, $deparse->{that}->{$topic}, $tagged ? "indent" : 0);
+		}
+
 		if ($tagged) {
 			print {$fh} "< topic\n\n";
 		}
@@ -1840,7 +1875,8 @@ sub _write_triggers {
 }
 
 sub _write_wrapped {
-	my ($self, $line, $sep, $indent) = @_;
+	my ($self, $line, $sep, $indent, $width) = @_;
+	$width ||= 78;
 
 	my $id = $indent ? "\t" : "";
 
@@ -1858,7 +1894,7 @@ sub _write_wrapped {
 	while (scalar(@words)) {
 		push (@buf, shift(@words));
 		$line = join($sep, @buf);
-		if (length $line > 78) {
+		if (length $line > $width) {
 			# Need to word wrap.
 			unshift(@words, pop(@buf)); # Undo
 			push (@lines, join($sep,@buf));
@@ -1962,6 +1998,7 @@ sub setSubroutine {
 	my ($self,$name,$sub) = @_;
 
 	$self->{objects}->{$name} = $sub;
+	$self->{objlangs}->{$name} = "perl";
 	return 1;
 }
 
@@ -2530,7 +2567,7 @@ sub _getreply {
 					my $lastReply = $self->{client}->{$user}->{__history__}->{reply}->[0];
 
 					# Format the bot's last reply the same as the human's.
-					$lastReply = $self->_formatMessage ($lastReply);
+					$lastReply = $self->_formatMessage ($lastReply, "lastReply");
 
 					$self->debug ("lastReply: $lastReply");
 
@@ -2873,23 +2910,29 @@ sub _reply_regexp {
 	}
 
 	# Filter input tags.
-	$regexp =~ s/<input>/$self->{client}->{$user}->{__history__}->{input}->[0]/ig;
-	$regexp =~ s/<reply>/$self->{client}->{$user}->{__history__}->{reply}->[0]/ig;
-	while ($regexp =~ /<input([0-9])>/i) {
-		my $index = $1;
-		my (@arrInput) = @{$self->{client}->{$user}->{__history__}->{input}};
-		unshift (@arrInput,'');
-		my $line = $arrInput[$index];
-		$line = $self->_formatMessage ($line);
-		$regexp =~ s/<input$index>/$line/ig;
+	if ($regexp =~ /<input/i) {
+		my $firstInput = $self->_formatMessage($self->{client}->{$user}->{__history__}->{input}->[0] || "undefined", "botReply");
+		$regexp =~ s/<input>/$firstInput/ig;
+		while ($regexp =~ /<input([1-9])>/i) {
+			my $index = $1;
+			my (@arrInput) = @{$self->{client}->{$user}->{__history__}->{input}};
+			unshift (@arrInput,'');
+			my $line = $arrInput[$index];
+			$line = $self->_formatMessage ($line, "botReply");
+			$regexp =~ s/<input$index>/$line/ig;
+		}
 	}
-	while ($regexp =~ /<reply([0-9])>/i) {
-		my $index = $1;
-		my (@arrReply) = @{$self->{client}->{$user}->{__history__}->{reply}};
-		unshift (@arrReply,'');
-		my $line = $arrReply[$index];
-		$line = $self->_formatMessage ($line);
-		$regexp =~ s/<reply$index>/$line/ig;
+	if ($regexp =~ /<reply/i) {
+		my $firstReply = $self->_formatMessage($self->{client}->{$user}->{__history__}->{reply}->[0] || "undefined", "botReply");
+		$regexp =~ s/<reply>/$firstReply/ig;
+		while ($regexp =~ /<reply([1-9])>/i) {
+			my $index = $1;
+			my (@arrReply) = @{$self->{client}->{$user}->{__history__}->{reply}};
+			unshift (@arrReply,'');
+			my $line = $arrReply[$index];
+			$line = $self->_formatMessage ($line, "botReply");
+			$regexp =~ s/<reply$index>/$line/ig;
+		}
 	}
 
 	return $regexp;
@@ -2957,60 +3000,6 @@ sub processTags {
 		}
 		$reply =~ s/\{random\}(.+?)\{\/random\}/$output/i;
 	}
-	while ($reply =~ /<bot (.+?)=(.+?)>/i) {
-		my ($what,$is) = ($1, $2);
-		$self->{bot}->{$what} = $is;
-		$reply =~ s/<bot (.+?)=(.+?)>//i;
-	}
-	while ($reply =~ /<env (.+?)=(.+?)>/i) {
-		my ($what,$is) = ($1, $2);
-
-		# Reserved?
-		my $reserved = 0;
-		foreach my $res (@{$self->{reserved}}) {
-			if ($res eq $what) {
-				$reserved = 1;
-				last;
-			}
-		}
-
-		if ($reserved) {
-			$self->{globals}->{$what} = $is;
-		}
-		else {
-			$self->{$what} = $is;
-		}
-
-		$reply =~ s/<env (.+?)=(.+?)>//i;
-	}
-	while ($reply =~ /<bot (.+?)>/i) {
-		my $val = (exists $self->{bot}->{$1} ? $self->{bot}->{$1} : 'undefined');
-		$reply =~ s/<bot (.+?)>/$val/i;
-	}
-	while ($reply =~ /<env (.+?)>/i) {
-		my $var = $1;
-		my $val = '';
-		if (exists $self->{globals}->{$var}) {
-			$val = $self->{globals}->{$var};
-		}
-		else {
-			my $reserved = 0;
-			foreach my $res (@{$self->{reserved}}) {
-				if ($res eq $var) {
-					$reserved = 1;
-				}
-			}
-
-			if (not $reserved) {
-				$val = (exists $self->{$var} ? $self->{$var} : 'undefined');
-			}
-			else {
-				$val = "(reserved)";
-			}
-		}
-
-		$reply =~ s/<env (.+?)>/$val/i;
-	}
 	while ($reply =~ /\{\!(.+?)\}/i) {
 		# Just stream this back through.
 		$self->stream ("! $1");
@@ -3041,59 +3030,117 @@ sub processTags {
 		$lower = $self->_stringUtil ('lower',$lower);
 		$reply =~ s/\{lowercase\}(.+?)\{\/lowercase\}/$lower/i;
 	}
-	while ($reply =~ /<set (.+?)=(.+?)>/i) {
-		# Set a user variable.
-		$self->debug ("Set uservar $1 => $2");
-		$self->{client}->{$user}->{$1} = $2;
-		$reply =~ s/<set (.+?)=(.+?)>//i;
-	}
-	while ($reply =~ /<(add|sub|mult|div) (.+?)=(.+?)>/i) {
-		# Mathematic modifiers.
-		my $mod = lc($1);
-		my $var = $2;
-		my $value = $3;
-		my $output = '';
 
-		# Initialize the variable?
-		if (!exists $self->{client}->{$user}->{$var}) {
-			$self->{client}->{$user}->{$var} = 0;
-		}
+	# Handle all variable-related tags with an iterative regexp approach,
+	# to allow for nesting of tags in arbitrary ways (think <set a=<get b>>)
+	# Dummy out the <call> tags first, because we don't handle them right here.
+	$reply =~ s/<call>/{__call__}/og;
+	$reply =~ s/<\/call>/{\/__call__}/og;
+	while (1) {
+		# This regexp will match a <tag> which contains no other tag inside it,
+		# i.e. in the case of <set a=<get b>> it will match <get b> but not the
+		# <set> tag, on the first pass. The second pass will get the <set> tag,
+		# and so on.
+		if ($reply =~ /<([^<]+?)>/) {
+			my $match  = $1;
+			my @parts  = split(/\s+/, $match, 2);
+			my $tag    = lc($parts[0]);
+			my $data   = $parts[1] || "";
+			my $insert = ""; # Result of the tag evaluation.
 
-		# Only modify numeric variables.
-		if ($self->{client}->{$user}->{$var} !~ /^[0-9\-\.]+$/) {
-			$output = "[ERR: Can't Modify Non-Numeric Variable $var]";
-		}
-		elsif ($value =~ /^[^0-9\-\.]$/) {
-			$output = "[ERR: Math Can't \"$mod\" Non-Numeric Value $value]";
-		}
-		else {
-			# Modify the variable.
-			if ($mod eq 'add') {
-				$self->{client}->{$user}->{$var} += $value;
-			}
-			elsif ($mod eq 'sub') {
-				$self->{client}->{$user}->{$var} -= $value;
-			}
-			elsif ($mod eq 'mult') {
-				$self->{client}->{$user}->{$var} *= $value;
-			}
-			elsif ($mod eq 'div') {
-				# Don't divide by zero.
-				if ($value == 0) {
-					$output = "[ERR: Can't Divide By Zero]";
+			# Handle the tags.
+			if ($tag eq "bot" or $tag eq "env") {
+				# <bot> and <env> tags are similar.
+				my ($what, $is) = split(/=/, $data, 2);
+				my $target = $self->{bot};
+				if ($tag eq "env") {
+					# Reserved?
+					my $reserved = 0;
+					foreach my $res (@{$self->{reserved}}) {
+						if ($res eq $what) {
+							$reserved = 1;
+							last;
+						}
+					}
+					if ($reserved) {
+						$target = $self->{globals};
+					}
+					else {
+						$target = $self;
+					}
+				}
+
+				# Updating?
+				if ($data =~ /=/) {
+					$self->debug("Set $tag variable $what => $is");
+					$target->{$what} = $is;
 				}
 				else {
-					$self->{client}->{$user}->{$var} /= $value;
+					$insert = exists $target->{$what} ? $target->{$what} : "undefined";
 				}
 			}
-		}
+			elsif ($tag eq "set") {
+				# <set> user vars.
+				my ($what, $is) = split(/=/, $data, 2);
+				$self->debug("Set uservar $what => $is");
+				$self->{client}->{$user}->{$what} = $is;
+			}
+			elsif ($tag =~ /^(?:add|sub|mult|div)$/) {
+				my ($var, $value) = split(/=/, $data, 2);
 
-		$reply =~ s/<(add|sub|mult|div) (.+?)=(.+?)>/$output/i;
-	}
-	while ($reply =~ /<get (.+?)>/i) {
-		my $val = (exists $self->{client}->{$user}->{$1} ? $self->{client}->{$user}->{$1} : 'undefined');
-		$reply =~ s/<get (.+?)>/$val/i;
+				# Initialize the value?
+				if (!exists $self->{client}->{$user}->{$var}) {
+					$self->{client}->{$user}->{$var} = 0;
+				}
+
+				# Sanity checks.
+				if ($self->{client}->{$user}->{$var} !~ /^[0-9\-\.]+$/) {
+					$insert = "[ERR: Can't Modify Non-Numeric Variable $var]";
+				}
+				elsif ($value =~ /^[^0-9\-\.]$/) {
+					$insert = "[ERR: Math Can't '$tag' Non-Numeric Value $value]";
+				}
+				else {
+					# Modify the variable.
+					if ($tag eq "add") {
+						$self->{client}->{$user}->{$var} += $value;
+					}
+					elsif ($tag eq "sub") {
+						$self->{client}->{$user}->{$var} -= $value;
+					}
+					elsif ($tag eq "mult") {
+						$self->{client}->{$user}->{$var} *= $value;
+					}
+					elsif ($tag eq "div") {
+						# Don't divide by zero.
+						if ($value == 0) {
+							$insert = "[ERR: Can't Divide By Zero]";
+						}
+						else {
+							$self->{client}->{$user}->{$var} /= $value;
+						}
+					}
+				}
+			}
+			elsif ($tag eq "get") {
+				$insert = (exists $self->{client}->{$user}->{$data} ? $self->{client}->{$user}->{$data} : "undefined");
+			}
+			else {
+				# Might be HTML tag, it's unrecognized. Preserve it.
+				$insert = "\x00$match\x01";
+			}
+
+			$reply =~ s/<$match>/$insert/i;
+		}
+		else {
+			last; # No more tags remaining.
+		}
 	}
+
+	# Recover mangled HTML-like tag parts.
+	$reply =~ s/\x00/</g;
+	$reply =~ s/\x01/>/g;
+
 	if ($reply =~ /\{topic=(.+?)\}/i) {
 		# Set the user's topic.
 		$self->debug ("Topic set to $1");
@@ -3110,6 +3157,8 @@ sub processTags {
 		);
 		$reply =~ s/\{\@(.+?)\}/$subreply/i;
 	}
+	$reply =~ s/\{__call__\}/<call>/g;
+	$reply =~ s/\{\/__call__\}/<\/call>/g;
 	while ($reply =~ /<call>(.+?)<\/call>/i) {
 		my ($obj,@args) = split(/\s+/, $1);
 		my $output = '';
@@ -3137,7 +3186,7 @@ sub processTags {
 }
 
 sub _formatMessage {
-	my ($self,$string) = @_;
+	my ($self,$string, $botReply) = @_;
 
 	# Lowercase it.
 	$string = lc($string);
@@ -3171,6 +3220,11 @@ sub _formatMessage {
 	if ($self->{utf8}) {
 		# Backslashes and HTML tags
 		$string =~ s/[\\<>]//g;
+
+		# If formatting the bot's last reply for %Previous, also remove punctuation.
+		if ($botReply) {
+			$string =~ s/[.?,!;:@#$%^&*()\-+]//g;
+		}
 	} else {
 		$string =~ s/[^A-Za-z0-9 ]//g;
 	}
@@ -3313,6 +3367,24 @@ L<http://www.rivescript.com/> - The official homepage of RiveScript.
 
 =head1 CHANGES
 
+  1.38  Jul 21 2015
+  - New algorithm for handling variable tags (<get>, <set>, <add>, <sub>,
+    <mult>, <div>, <bot> and <env>) that allows for iterative nesting of these
+    tags (for example, <set copy=<get orig>> will work now).
+  - Fix trigger sorting so that triggers with matching word counts are sorted
+    by length descending.
+  - Add support for `! local concat` option to override concatenation mode
+    (file scoped)
+  - Bugfix where Perl object macros set via `setSubroutine()` failed to load
+    because they were missing a programming language internally.
+
+  1.36  Nov 26 2014
+  - Relicense under the MIT License.
+  - Strip punctuation from the bot's responses in UTF-8 mode to
+    support compatibility with %Previous.
+  - Bugfix in deparse(): If you had two matching triggers, one with a %Previous
+    and one without, you'd lose the data for one of them in the output.
+
   1.34  Feb 26 2014
   - Update README.md to include module documentation for github.
   - Fixes to META.yml
@@ -3335,101 +3407,7 @@ L<http://www.rivescript.com/> - The official homepage of RiveScript.
     instead of .rs (which conflicts with the Rust programming language).
     Backwards compatibility remains to load .rs files, though.
 
-  1.28  Aug 14 2012
-  - FIXED: Typos in RiveScript::WD (Bug #77618)
-  - Added constants RS_ERR_MATCH and RS_ERR_REPLY.
-
-  1.26  May 29 2012
-  - Added EXE_FILES to Makefile.PL so the rivescript utility installs
-    correctly.
-
-  1.24  May 15 2012
-  - Fixed: having a single-line, multiline comment, e.g. /* ... */
-  - Fixed: you can use <input> and <reply> in triggers now, instead of only
-    <input1>-<input9> and <reply1>-<reply9>
-  - When a trigger consists of nothing but multiple wildcard symbols, sort
-    the trigger by length, this way you can have '* * * * *' type triggers
-    still work correctly (each <star> tag would get one word, with the final
-    <star> collecting the remainder).
-  - Backported new feature from Python lib: you can now use <bot> and <env>
-    to SET variables (eg. <bot mood=happy>). The {!...} tag is deprecated.
-  - New feature: deparse() will return a Perl data structure representing all
-    of the RiveScript code parsed by the module so far. This way you can build
-    a user interface for editing replies without requiring a user to edit the
-    code directly.
-  - New method: write() will use deparse() to write a RiveScript document using
-    all of the in-memory triggers/responses/etc.
-  - Cleaned up the POD documentation, put POD code along side the Perl functions
-    it documents, removed useless bloat from the docs.
-  - POD documentation now only shows recent changes. For older changes, see the
-    "CHANGES" file in the distribution.
-  - Removed the `rsup` script from the distribution (it upgrades RiveScript 1.x
-    code to 2.x; there probably isn't any 1.x code out in the wild anyway).
-
-  1.22  Sep 22 2011
-  - Cleaned up the documentation of RiveScript; moved the JavaScript object
-    example to a separate document in the `docs' directory.
-  - Obsoleted the `rsdemo` command that used to ship with the distribution. In
-    its place is `rivescript`, which can also be used non-interactively so that a
-    third party, non-Perl application could still make use of RiveScript.
-  - RiveScript.pm is now dual licensed. It uses the GPLv2 for open source
-    applications as before, but you can contact the author for details if you
-    want to use RiveScript.pm in a closed source commercial application.
-
-  1.20  Jul 30 2009
-  - Added automatic syntax checking when parsing RiveScript code. Also added
-    'strict mode' - if true (default), a syntax error is a fatal error. If false,
-    a syntax error is a warning, and RiveScript aborts processing the file any
-    further.
-  - Changed the behavior of "inherits" a bit: a new type has been added called
-    "includes" which does what the old "inherits" does (mixes the trigger list
-    of both topics together into the same pool). The new "inherits" option though
-    causes the trigger list from the source topic to be higher in matching priority
-    than the trigger list of the inherited topic.
-  - Moving to a new versioning scheme: development releases will have odd
-    version numbers, stable (CPAN) versions will have even numbers.
-  - Fixed the Eliza brain; in many places a <star2> was used when there was only one
-    star in the trigger. Fixes lots of issues with Eliza.
-  - Bugfix: recursion depth limits weren't taken into account when the {@} tag
-    was responsible for a redirection. Fixed.
-  - Bugfix: there was a problem in the regular expression that counts real words
-    while sorting triggers, so that triggers with *'s in them weren't sorted
-    properly and would therefore cause matching issues.
-  - Bugfix: when the internal _getreply is called because of a recursive
-    redirection (@, {@}), the %previous tags should be ignored. They weren't.
-    since "lastreply" is always the same no matter how deeply recursive _getreply
-    is going, it could result in some infinite recursion in rare cases. Fixed.
-  - Bugfix: using a reserved name as a global variable wasn't working properly
-    and would crash RiveScript. Fixed.
-
-  1.19  Apr 12 2009
-  - Added support for defining custom object handlers for non-Perl programming
-    languages.
-  - All the methods like setGlobal, setVariable, setUservar, etc. will now
-    accept undef or "<undef>" as values - this will delete the variables.
-  - There are no reserved global variable names anymore. Now, if a variable name
-    would conflict with a reserved name, it is put into a "protected" space
-    elsewhere in the object. Still take note of which names are reserved though.
-
-  1.18  Dec 31 2008
-  - Added support for topics to inherit their triggers from other topics.
-    e.g. > topic alpha inherits beta
-  - Fixed some bugs related to !array with ^continue's, and expanded its
-    functionality therein.
-  - Updated the getUservars() function to optionally be able to get just a specific
-    variable from the user's data. Added getUservar() as a grammatically correct
-    alias to this new functionality.
-  - Added the functions freezeUservars() and thawUservars() to back up and
-    restore a user's variables.
-  - Added the function lastMatch(), which returns the text of the trigger that
-    matched the user's last message.
-  - The # command for RiveScript comments has been deprecated in revision 7 of
-    the RiveScript Working Draft. The Perl module will now emit warnings each
-    time the # comments are processed.
-  - Modified a couple of triggers in the default Eliza brain to improve matching
-    issues therein.
-  - +Triggers can contain user <get> tags now.
-  - Updated the RiveScript Working Draft.
+See the `Changes` file for older change history.
 
 =head1 AUTHOR
 
@@ -3441,26 +3419,26 @@ bot, chatbot, chatterbot, chatter bot, reply, replies, script, aiml, alpha
 
 =head1 COPYRIGHT AND LICENSE
 
-The Perl RiveScript interpreter is dual licensed as of version 1.22.
-For open source applications the module is using the GNU General Public
-License. If you'd like to use the RiveScript module in a closed source or
-commercial application, contact the author for more information.
+  The MIT License (MIT)
 
-  RiveScript - Rendering Intelligence Very Easily
-  Copyright (C) 2014 Noah Petherbridge
+  Copyright (c) 2015 Noah Petherbridge
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+  Permission is hereby granted, free of charge, to any person obtaining a copy
+  of this software and associated documentation files (the "Software"), to deal
+  in the Software without restriction, including without limitation the rights
+  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+  copies of the Software, and to permit persons to whom the Software is
+  furnished to do so, subject to the following conditions:
 
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+  The above copyright notice and this permission notice shall be included in all
+  copies or substantial portions of the Software.
 
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+  SOFTWARE.
 
 =cut
